@@ -34,11 +34,26 @@
 #' validation functions. The validation function can be used directly on a data
 #' table or with an *agent* object (technically, a `ptblank_agent` object)
 #' whereas the expectation and test functions can only be used with a data
-#' table. The types of data tables that can be used include data frames,
-#' tibbles, database tables (`tbl_dbi`), and Spark DataFrames (`tbl_spark`).
-#' Each validation step or expectation will operate over the number of test
-#' units that is equal to the number of rows in the table (after any
+#' table. Each validation step or expectation will operate over the number of
+#' test units that is equal to the number of rows in the table (after any
 #' `preconditions` have been applied).
+#' 
+#' @section Supported Input Tables:
+#' The types of data tables that are officially supported are:
+#' 
+#'  - data frames (`data.frame`) and tibbles (`tbl_df`)
+#'  - Spark DataFrames (`tbl_spark`)
+#'  - the following database tables (`tbl_dbi`):
+#'    - *PostgreSQL* tables (using the `RPostgres::Postgres()` as driver)
+#'    - *MySQL* tables (with `RMySQL::MySQL()`)
+#'    - *Microsoft SQL Server* tables (via **odbc**)
+#'    - *BigQuery* tables (using `bigrquery::bigquery()`)
+#'    - *DuckDB* tables (through `duckdb::duckdb()`)
+#'    - *SQLite* (with `RSQLite::SQLite()`)
+#'    
+#' Other database tables may work to varying degrees but they haven't been
+#' formally tested (so be mindful of this when using unsupported backends with
+#' **pointblank**).
 #'
 #' @section Column Names:
 #' If providing multiple column names to `columns`, the result will be an
@@ -134,8 +149,9 @@
 #' a validation step is expressed in R code and in the corresponding YAML
 #' representation.
 #' 
-#' ```
-#' # R statement
+#' R statement:
+#' 
+#' ```r
 #' agent %>% 
 #'   col_vals_between(
 #'     columns = vars(a),
@@ -149,8 +165,11 @@
 #'     label = "The `col_vals_between()` step.",
 #'     active = FALSE
 #'   )
+#' ```
 #' 
-#' # YAML representation
+#' YAML representation:
+#' 
+#' ```yaml
 #' steps:
 #' - col_vals_between:
 #'     columns: vars(a)
@@ -196,94 +215,102 @@
 #'   called primarily for its potential side-effects (e.g., signaling failure).
 #'   The test function returns a logical value.
 #'   
-#' @examples
-#' # The `small_table` dataset in the
-#' # package has a column of numeric
-#' # values in `c` (there are a few NAs
-#' # in that column); the following
-#' # examples will validate the values
-#' # in that numeric column
+#' @section Examples:
 #' 
-#' # A: Using an `agent` with validation
-#' #    functions and then `interrogate()`
+#' The `small_table` dataset in the package has a column of numeric values in
+#' `c` (there are a few NAs in that column). The following examples will
+#' validate the values in that numeric column.
 #' 
-#' # Validate that values in column `c`
-#' # are all between `1` and `9`; because
-#' # there are NA values, we'll choose to
-#' # let those pass validation by setting
-#' # `na_pass = TRUE`
+#' ```{r}
+#' small_table
+#' ```
+#' 
+#' ## A: Using an `agent` with validation functions and then `interrogate()`
+#' 
+#' Validate that values in column `c` are all between `1` and `9`. Because there
+#' are `NA` values, we'll choose to let those pass validation by setting
+#' `na_pass = TRUE`.
+#' 
+#' ```r
 #' agent <-
-#'   create_agent(small_table) %>%
+#'   create_agent(tbl = small_table) %>%
 #'   col_vals_between(
-#'     vars(c), 1, 9, na_pass = TRUE
+#'     columns = vars(c),
+#'     left = 1, right = 9,
+#'     na_pass = TRUE
 #'   ) %>%
 #'   interrogate()
-#'   
-#' # Determine if this validation
-#' # had no failing test units (there
-#' # are 13 test units, one for each row)
-#' all_passed(agent)
+#' ```
 #' 
-#' # Calling `agent` in the console
-#' # prints the agent's report; but we
-#' # can get a `gt_tbl` object directly
-#' # with `get_agent_report(agent)`
+#' Printing the `agent` in the console shows the validation report in the
+#' Viewer. Here is an excerpt of validation report, showing the single entry
+#' that corresponds to the validation step demonstrated here.
 #' 
-#' # B: Using the validation function
-#' #    directly on the data (no `agent`)
+#' \if{html}{
+#' \out{
+#' `r pb_get_image_tag(file = "man_col_vals_between_1.png")`
+#' }
+#' }
 #' 
-#' # This way of using validation functions
-#' # acts as a data filter: data is passed
-#' # through but should `stop()` if there
-#' # is a single test unit failing; the
-#' # behavior of side effects can be
-#' # customized with the `actions` option
+#' ## B: Using the validation function directly on the data (no `agent`)
+#' 
+#' This way of using validation functions acts as a data filter. Data is passed
+#' through but should `stop()` if there is a single test unit failing. The
+#' behavior of side effects can be customized with the `actions` option.
+#' 
+#' ```{r}
 #' small_table %>%
 #'   col_vals_between(
-#'     vars(c), 1, 9, na_pass = TRUE
+#'     columns = vars(c),
+#'     left = 1, right = 9,
+#'     na_pass = TRUE
 #'   ) %>%
 #'   dplyr::pull(c)
+#' ```
 #'
-#' # C: Using the expectation function
+#' ## C: Using the expectation function
 #' 
-#' # With the `expect_*()` form, we would
-#' # typically perform one validation at a
-#' # time; this is primarily used in
-#' # testthat tests
+#' With the `expect_*()` form, we would typically perform one validation at a
+#' time. This is primarily used in **testthat** tests.
+#' 
+#' ```r
 #' expect_col_vals_between(
-#'   small_table, vars(c), 1, 9,
+#'   small_table, columns = vars(c),
+#'   left = 1, right = 9,
 #'   na_pass = TRUE
 #' )
+#' ```
 #' 
-#' # D: Using the test function
+#' ## D: Using the test function
 #' 
-#' # With the `test_*()` form, we should
-#' # get a single logical value returned
-#' # to us
+#' With the `test_*()` form, we should get a single logical value returned to
+#' us.
+#' 
+#' ```{r}
 #' small_table %>%
 #'   test_col_vals_between(
-#'     vars(c), 1, 9,
+#'     columns = vars(c),
+#'     left = 1, right = 9,
 #'     na_pass = TRUE
 #'   )
+#' ```
 #'
-#' # An additional note on the bounds for
-#' # this function: they are inclusive by
-#' # default (i.e., values of exactly 1
-#' # and 9 will pass); we can modify the
-#' # inclusiveness of the upper and lower
-#' # bounds with the `inclusive` option,
-#' # which is a length-2 logical vector
+#' An additional note on the bounds for this function: they are inclusive by
+#' default (i.e., values of exactly `1` and `9` will pass). We can modify the
+#' inclusiveness of the upper and lower bounds with the `inclusive` option,
+#' which is a length-2 logical vector.
 #' 
-#' # Testing with the upper bound being
-#' # non-inclusive, we get `FALSE` since
-#' # two values are `9` and they now fall
-#' # outside of the upper (or right) bound
+#' Testing with the upper bound being non-inclusive, we get `FALSE` since two
+#' values are `9` and they now fall outside of the upper (or right) bound.
+#' 
+#' ```{r}
 #' small_table %>%
 #'   test_col_vals_between(
-#'     vars(c), 1, 9,
+#'     columns = vars(c), left = 1, right = 9,
 #'     inclusive = c(TRUE, FALSE),
 #'     na_pass = TRUE
 #'   )
+#' ```
 #' 
 #' @family validation functions
 #' @section Function ID:
@@ -297,19 +324,21 @@ NULL
 #' @rdname col_vals_between
 #' @import rlang
 #' @export
-col_vals_between <- function(x,
-                             columns,
-                             left,
-                             right,
-                             inclusive = c(TRUE, TRUE),
-                             na_pass = FALSE,
-                             preconditions = NULL,
-                             segments = NULL,
-                             actions = NULL,
-                             step_id = NULL,
-                             label = NULL,
-                             brief = NULL,
-                             active = TRUE) {
+col_vals_between <- function(
+    x,
+    columns,
+    left,
+    right,
+    inclusive = c(TRUE, TRUE),
+    na_pass = FALSE,
+    preconditions = NULL,
+    segments = NULL,
+    actions = NULL,
+    step_id = NULL,
+    label = NULL,
+    brief = NULL,
+    active = TRUE
+) {
   
   # Get `columns` as a label
   columns_expr <- 
@@ -416,14 +445,16 @@ col_vals_between <- function(x,
 #' @rdname col_vals_between
 #' @import rlang
 #' @export
-expect_col_vals_between <- function(object,
-                                    columns,
-                                    left,
-                                    right,
-                                    inclusive = c(TRUE, TRUE),
-                                    na_pass = FALSE,
-                                    preconditions = NULL,
-                                    threshold = 1) {
+expect_col_vals_between <- function(
+    object,
+    columns,
+    left,
+    right,
+    inclusive = c(TRUE, TRUE),
+    na_pass = FALSE,
+    preconditions = NULL,
+    threshold = 1
+) {
   
   fn_name <- "expect_col_vals_between"
   
@@ -506,14 +537,16 @@ expect_col_vals_between <- function(object,
 #' @rdname col_vals_between
 #' @import rlang
 #' @export
-test_col_vals_between <- function(object,
-                                  columns,
-                                  left,
-                                  right,
-                                  inclusive = c(TRUE, TRUE),
-                                  na_pass = FALSE,
-                                  preconditions = NULL,
-                                  threshold = 1) {
+test_col_vals_between <- function(
+    object,
+    columns,
+    left,
+    right,
+    inclusive = c(TRUE, TRUE),
+    na_pass = FALSE,
+    preconditions = NULL,
+    threshold = 1
+) {
   
   vs <- 
     create_agent(tbl = object, label = "::QUIET::") %>%
