@@ -16,6 +16,7 @@
 # https://rich-iannone.github.io/pointblank/LICENSE.html
 #
 
+
 #' Are column data decreasing by row?
 #'
 #' @description
@@ -28,11 +29,26 @@
 #' movements up to a certain threshold. The validation function can be used
 #' directly on a data table or with an *agent* object (technically, a
 #' `ptblank_agent` object) whereas the expectation and test functions can only
-#' be used with a data table. The types of data tables that can be used include
-#' data frames, tibbles, database tables (`tbl_dbi`), and Spark DataFrames
-#' (`tbl_spark`). Each validation step or expectation will operate over the
-#' number of test units that is equal to the number of rows in the table (after
-#' any `preconditions` have been applied).
+#' be used with a data table. Each validation step or expectation will operate
+#' over the number of test units that is equal to the number of rows in the
+#' table (after any `preconditions` have been applied).
+#' 
+#' @section Supported Input Tables:
+#' The types of data tables that are officially supported are:
+#' 
+#'  - data frames (`data.frame`) and tibbles (`tbl_df`)
+#'  - Spark DataFrames (`tbl_spark`)
+#'  - the following database tables (`tbl_dbi`):
+#'    - *PostgreSQL* tables (using the `RPostgres::Postgres()` as driver)
+#'    - *MySQL* tables (with `RMySQL::MySQL()`)
+#'    - *Microsoft SQL Server* tables (via **odbc**)
+#'    - *BigQuery* tables (using `bigrquery::bigquery()`)
+#'    - *DuckDB* tables (through `duckdb::duckdb()`)
+#'    - *SQLite* (with `RSQLite::SQLite()`)
+#'    
+#' Other database tables may work to varying degrees but they haven't been
+#' formally tested (so be mindful of this when using unsupported backends with
+#' **pointblank**).
 #'
 #' @section Column Names:
 #' If providing multiple column names to `columns`, the result will be an
@@ -128,8 +144,9 @@
 #' `col_vals_decreasing()` as a validation step is expressed in R code and in
 #' the corresponding YAML representation.
 #' 
-#' ```
-#' # R statement
+#' R statement:
+#' 
+#' ```r
 #' agent %>% 
 #'   col_vals_decreasing(
 #'     columns = vars(a),
@@ -141,9 +158,12 @@
 #'     actions = action_levels(warn_at = 0.1, stop_at = 0.2),
 #'     label = "The `col_vals_decreasing()` step.",
 #'     active = FALSE
-#'   ) %>% yaml_agent_string()
+#'   )
+#' ```
 #' 
-#' # YAML representation
+#' YAML representation:
+#' 
+#' ```yaml
 #' steps:
 #' - col_vals_decreasing:
 #'     columns: vars(a)
@@ -186,15 +206,14 @@
 #'   called primarily for its potential side-effects (e.g., signaling failure).
 #'   The test function returns a logical value.
 #' 
-#' @examples
-#' # The `game_revenue` dataset in
-#' # the package has the column
-#' # `session_start`, which contains
-#' # date-time values; let's create
-#' # a column of difftime values (in
-#' # `time_left`) that describes the
-#' # time remaining in the month
-#' # relative to the session start
+#' @section Examples:
+#' 
+#' The `game_revenue` dataset in the package has the column `session_start`,
+#' which contains date-time values. Let's create a column of difftime values (in
+#' `time_left`) that describes the time remaining in the month relative to the
+#' session start.
+#' 
+#' ```{r}
 #' game_revenue_2 <-
 #'   game_revenue %>%
 #'   dplyr::mutate(
@@ -204,77 +223,80 @@
 #'       ) - session_start
 #'   )
 #' 
-#' # Let's ensure that the difftime
-#' # values in the new `time_left`
-#' # column has values that are
-#' # decreasing from top to bottom
-#'
-#' # A: Using an `agent` with validation
-#' #    functions and then `interrogate()`
+#' game_revenue_2
+#' ```
 #' 
-#' # Validate that all difftime values
-#' # in the column `time_left` are
-#' # decreasing, and, allow for repeating
-#' # values (`allow_stationary` will be
-#' # set to `TRUE`)
+#' Let's ensure that the `"difftime"` values in the new `time_left` column has
+#' values that are decreasing from top to bottom.
+#'
+#' ## A: Using an `agent` with validation functions and then `interrogate()`
+#' 
+#' Validate that all `"difftime"` values in the column `time_left` are
+#' decreasing, and, allow for repeating values (`allow_stationary` will be set
+#' to `TRUE`).
+#' 
+#' ```r
 #' agent <-
-#'   create_agent(game_revenue_2) %>%
+#'   create_agent(tbl = game_revenue_2) %>%
 #'   col_vals_decreasing(
-#'     vars(time_left),
+#'     columns = vars(time_left),
 #'     allow_stationary = TRUE
 #'   ) %>%
 #'   interrogate()
-#'   
-#' # Determine if this validation
-#' # had no failing test units (there
-#' # are 2000 test units)
-#' all_passed(agent)
+#' ```
 #' 
-#' # Calling `agent` in the console
-#' # prints the agent's report; but we
-#' # can get a `gt_tbl` object directly
-#' # with `get_agent_report(agent)`
+#' Printing the `agent` in the console shows the validation report in the
+#' Viewer. Here is an excerpt of validation report, showing the single entry
+#' that corresponds to the validation step demonstrated here.
 #' 
-#' # B: Using the validation function
-#' #    directly on the data (no `agent`)
+#' \if{html}{
+#' \out{
+#' `r pb_get_image_tag(file = "man_col_vals_decreasing_1.png")`
+#' }
+#' }
 #' 
-#' # This way of using validation functions
-#' # acts as a data filter: data is passed
-#' # through but should `stop()` if there
-#' # is a single test unit failing; the
-#' # behavior of side effects can be
-#' # customized with the `actions` option
+#' ## B: Using the validation function directly on the data (no `agent`)
+#' 
+#' This way of using validation functions acts as a data filter. Data is passed
+#' through but should `stop()` if there is a single test unit failing. The
+#' behavior of side effects can be customized with the `actions` option.
+#' 
+#' ```{r}
 #' game_revenue_2 %>%
 #'   col_vals_decreasing(
-#'     vars(time_left),
+#'     columns = vars(time_left),
 #'     allow_stationary = TRUE
 #'   ) %>%
 #'   dplyr::select(time_left) %>%
 #'   dplyr::distinct() %>%
 #'   dplyr::count()
+#' ```
 #'
-#' # C: Using the expectation function
+#' ## C: Using the expectation function
 #' 
-#' # With the `expect_*()` form, we would
-#' # typically perform one validation at a
-#' # time; this is primarily used in
-#' # testthat tests
+#' With the `expect_*()` form, we would typically perform one validation at a
+#' time. This is primarily used in **testthat** tests.
+#' 
+#' ```r
 #' expect_col_vals_decreasing(
 #'   game_revenue_2,
-#'   vars(time_left),
+#'   columns = vars(time_left),
 #'   allow_stationary = TRUE
 #' )
+#' ```
 #' 
-#' # D: Using the test function
+#' ## D: Using the test function
 #' 
-#' # With the `test_*()` form, we should
-#' # get a single logical value returned
-#' # to us
+#' With the `test_*()` form, we should get a single logical value returned to
+#' us.
+#' 
+#' ```{r}
 #' game_revenue_2 %>%
 #'   test_col_vals_decreasing(
-#'     vars(time_left),
+#'     columns = vars(time_left),
 #'     allow_stationary = TRUE
 #'   )
+#' ```
 #' 
 #' @family validation functions
 #' @section Function ID:
@@ -289,18 +311,20 @@ NULL
 #' @rdname col_vals_decreasing
 #' @import rlang
 #' @export
-col_vals_decreasing <- function(x,
-                                columns,
-                                allow_stationary = FALSE,
-                                increasing_tol = NULL,
-                                na_pass = FALSE,
-                                preconditions = NULL,
-                                segments = NULL,
-                                actions = NULL,
-                                step_id = NULL,
-                                label = NULL,
-                                brief = NULL,
-                                active = TRUE) {
+col_vals_decreasing <- function(
+    x,
+    columns,
+    allow_stationary = FALSE,
+    increasing_tol = NULL,
+    na_pass = FALSE,
+    preconditions = NULL,
+    segments = NULL,
+    actions = NULL,
+    step_id = NULL,
+    label = NULL,
+    brief = NULL,
+    active = TRUE
+) {
   
   # Get `columns` as a label
   columns_expr <- 
@@ -411,13 +435,15 @@ col_vals_decreasing <- function(x,
 #' @rdname col_vals_decreasing
 #' @import rlang
 #' @export
-expect_col_vals_decreasing <- function(object,
-                                       columns,
-                                       allow_stationary = FALSE,
-                                       increasing_tol = NULL,
-                                       na_pass = FALSE,
-                                       preconditions = NULL,
-                                       threshold = 1) {
+expect_col_vals_decreasing <- function(
+    object,
+    columns,
+    allow_stationary = FALSE,
+    increasing_tol = NULL,
+    na_pass = FALSE,
+    preconditions = NULL,
+    threshold = 1
+) {
   
   fn_name <- "expect_col_vals_decreasing"
   
@@ -491,13 +517,15 @@ expect_col_vals_decreasing <- function(object,
 #' @rdname col_vals_decreasing
 #' @import rlang
 #' @export
-test_col_vals_decreasing <- function(object,
-                                     columns,
-                                     allow_stationary = FALSE,
-                                     increasing_tol = NULL,
-                                     na_pass = FALSE,
-                                     preconditions = NULL,
-                                     threshold = 1) {
+test_col_vals_decreasing <- function(
+    object,
+    columns,
+    allow_stationary = FALSE,
+    increasing_tol = NULL,
+    na_pass = FALSE,
+    preconditions = NULL,
+    threshold = 1
+) {
   
   vs <- 
     create_agent(tbl = object, label = "::QUIET::") %>%
