@@ -64,6 +64,23 @@
 #' integer value (as an absolute threshold of failing test units) or a
 #' decimal value between `0` and `1` (serving as a fractional threshold of
 #' failing test units).
+#' 
+#' @section Supported Input Tables:
+#' The types of data tables that are officially supported are:
+#' 
+#'  - data frames (`data.frame`) and tibbles (`tbl_df`)
+#'  - Spark DataFrames (`tbl_spark`)
+#'  - the following database tables (`tbl_dbi`):
+#'    - *PostgreSQL* tables (using the `RPostgres::Postgres()` as driver)
+#'    - *MySQL* tables (with `RMySQL::MySQL()`)
+#'    - *Microsoft SQL Server* tables (via **odbc**)
+#'    - *BigQuery* tables (using `bigrquery::bigquery()`)
+#'    - *DuckDB* tables (through `duckdb::duckdb()`)
+#'    - *SQLite* (with `RSQLite::SQLite()`)
+#'    
+#' Other database tables may work to varying degrees but they haven't been
+#' formally tested (so be mindful of this when using unsupported backends with
+#' **pointblank**).
 #'
 #' @section Column Names:
 #' If providing multiple column names in any of the supplied validation steps,
@@ -123,25 +140,29 @@
 #' validation step is expressed in R code and in the corresponding YAML
 #' representation.
 #' 
-#' ```
-#' # R statement
+#' R statement:
+#' 
+#' ```r
 #' agent %>% 
 #'   serially(
-#'     ~ col_vals_lt(., vars(a), 8),
-#'     ~ col_vals_gt(., vars(c), vars(a)),
-#'     ~ col_vals_not_null(., vars(b)),
+#'     ~ col_vals_lt(., columns = vars(a), value = 8),
+#'     ~ col_vals_gt(., columns = vars(c), value = vars(a)),
+#'     ~ col_vals_not_null(., columns = vars(b)),
 #'     preconditions = ~ . %>% dplyr::filter(a < 10),
 #'     actions = action_levels(warn_at = 0.1, stop_at = 0.2), 
 #'     label = "The `serially()` step.",
 #'     active = FALSE
 #'   )
+#' ```
 #' 
-#' # YAML representation
+#' YAML representation:
+#' 
+#' ```yaml
 #' steps:
 #' - serially:
 #'     fns:
-#'     - ~col_vals_lt(., vars(a), 8)
-#'     - ~col_vals_gt(., vars(c), vars(a))
+#'     - ~col_vals_lt(., columns = vars(a), value = 8)
+#'     - ~col_vals_gt(., columns = vars(c), value = vars(a))
 #'     - ~col_vals_not_null(., vars(b))
 #'     preconditions: ~. %>% dplyr::filter(a < 10)
 #'     actions:
@@ -177,12 +198,13 @@
 #'   called primarily for its potential side-effects (e.g., signaling failure).
 #'   The test function returns a logical value.
 #'
-#' @examples
-#' # For all examples here, we'll use
-#' # a simple table with three numeric
-#' # columns (`a`, `b`, and `c`); this is
-#' # a very basic table but it'll be more
-#' # useful when explaining things later
+#' @section Examples:
+#' 
+#' For all examples here, we'll use a simple table with three numeric columns
+#' (`a`, `b`, and `c`). This is a very basic table but it'll be more useful when
+#' explaining things later.
+#' 
+#' ```{r}
 #' tbl <-
 #'   dplyr::tibble(
 #'     a = c(5, 2, 6),
@@ -191,102 +213,109 @@
 #'   )
 #'   
 #' tbl
+#' ```
 #'   
-#' # A: Using an `agent` with validation
-#' #    functions and then `interrogate()`
+#' ## A: Using an `agent` with validation functions and then `interrogate()`
 #' 
-#' # The `serially()` function can be set
-#' # up to perform a series of tests and
-#' # then perform a validation (only if
-#' # all tests pass); here, we are going
-#' # to (1) test whether columns `a` and
-#' # `b` are numeric, (2) check that both
-#' # don't have any `NA` values, and (3)
-#' # perform a finalizing validation that
-#' # checks whether values in `b` are
-#' # greater than values in `a`
+#' The `serially()` function can be set up to perform a series of tests and then
+#' perform a validation (only if all tests pass). Here, we are going to (1) test
+#' whether columns `a` and `b` are numeric, (2) check that both don't have any
+#' `NA` values, and (3) perform a finalizing validation that checks whether
+#' values in `b` are greater than values in `a`. We'll determine if this
+#' validation has any failing test units (there are 4 tests and a final
+#' validation).
+#' 
+#' ```r
 #' agent_1 <-
 #'   create_agent(tbl = tbl) %>%
 #'   serially(
-#'     ~ test_col_is_numeric(., vars(a, b)),
-#'     ~ test_col_vals_not_null(., vars(a, b)),
-#'     ~ col_vals_gt(., vars(b), vars(a))
+#'     ~ test_col_is_numeric(., columns = vars(a, b)),
+#'     ~ test_col_vals_not_null(., columns = vars(a, b)),
+#'     ~ col_vals_gt(., columns = vars(b), value = vars(a))
 #'     ) %>%
 #'   interrogate()
-#'   
-#' # Determine if this validation
-#' # had no failing test units (there are
-#' # 4 tests and a final validation)
-#' all_passed(agent_1)
+#' ```
 #' 
-#' # Calling `agent` in the console
-#' # prints the agent's report; but we
-#' # can get a `gt_tbl` object directly
-#' # with `get_agent_report(agent_1)`
+#' Printing the `agent` in the console shows the validation report in the
+#' Viewer. Here is an excerpt of validation report, showing the single entry
+#' that corresponds to the validation step demonstrated here.
 #' 
-#' # What's going on? All four of the tests
-#' # passed and so the final validation
-#' # occurred; there were no failing test
-#' # units in that either!
+#' \if{html}{
+#' \out{
+#' `r pb_get_image_tag(file = "man_serially_1.png")`
+#' }
+#' }
 #' 
-#' # The final validation is optional; here
-#' # is a different agent where only the
-#' # serial tests are performed
+#' What's going on? All four of the tests passed and so the final validation
+#' occurred. There were no failing test units in that either!
+#'
+#' The final validation is optional and so here is a variation where only the
+#' serial tests are performed.
+#' 
+#' ```r
 #' agent_2 <-
 #'   create_agent(tbl = tbl) %>%
 #'   serially(
-#'     ~ test_col_is_numeric(., vars(a, b)),
-#'     ~ test_col_vals_not_null(., vars(a, b))
+#'     ~ test_col_is_numeric(., columns = vars(a, b)),
+#'     ~ test_col_vals_not_null(., columns = vars(a, b))
 #'   ) %>%
 #'   interrogate()
-#'   
-#' # Everything is good here too:
-#' all_passed(agent_2)
+#' ```
 #' 
-#' # B: Using the validation function
-#' #    directly on the data (no `agent`)
+#' Everything is good here too:
 #' 
-#' # This way of using validation functions
-#' # acts as a data filter: data is passed
-#' # through but should `stop()` if there
-#' # is a single test unit failing; the
-#' # behavior of side effects can be
-#' # customized with the `actions` option
+#' \if{html}{
+#' \out{
+#' `r pb_get_image_tag(file = "man_serially_2.png")`
+#' }
+#' }
+#' 
+#' ## B: Using the validation function directly on the data (no `agent`)
+#' 
+#' This way of using validation functions acts as a data filter. Data is passed
+#' through but should `stop()` if there is a single test unit failing. The
+#' behavior of side effects can be customized with the `actions` option.
+#' 
+#' ```{r}
 #' tbl %>%
 #'   serially(
-#'     ~ test_col_is_numeric(., vars(a, b)),
-#'     ~ test_col_vals_not_null(., vars(a, b)),
-#'     ~ col_vals_gt(., vars(b), vars(a))
+#'     ~ test_col_is_numeric(., columns = vars(a, b)),
+#'     ~ test_col_vals_not_null(., columns = vars(a, b)),
+#'     ~ col_vals_gt(., columns = vars(b), value = vars(a))
 #'   )
+#' ```
 #'
-#' # C: Using the expectation function
+#' ## C: Using the expectation function
 #' 
-#' # With the `expect_*()` form, we would
-#' # typically perform one validation at a
-#' # time; this is primarily used in
-#' # testthat tests
+#' With the `expect_*()` form, we would typically perform one validation at a
+#' time. This is primarily used in **testthat** tests.
+#' 
+#' ```r
 #' expect_serially(
 #'   tbl,
-#'   ~ test_col_is_numeric(., vars(a, b)),
-#'   ~ test_col_vals_not_null(., vars(a, b)),
-#'   ~ col_vals_gt(., vars(b), vars(a))
+#'   ~ test_col_is_numeric(., columns = vars(a, b)),
+#'   ~ test_col_vals_not_null(., columns = vars(a, b)),
+#'   ~ col_vals_gt(., columns = vars(b), value = vars(a))
 #' )
+#' ```
 #' 
-#' # D: Using the test function
+#' ## D: Using the test function
 #' 
-#' # With the `test_*()` form, we should
-#' # get a single logical value returned
-#' # to us
+#' With the `test_*()` form, we should get a single logical value returned to
+#' us.
+#' 
+#' ```{r}
 #' tbl %>%
 #'   test_serially(
-#'     ~ test_col_is_numeric(., vars(a, b)),
-#'     ~ test_col_vals_not_null(., vars(a, b)),
-#'     ~ col_vals_gt(., vars(b), vars(a))
+#'     ~ test_col_is_numeric(., columns = vars(a, b)),
+#'     ~ test_col_vals_not_null(., columns = vars(a, b)),
+#'     ~ col_vals_gt(., columns = vars(b), value = vars(a))
 #'   )
+#' ```
 #'
 #' @family validation functions
 #' @section Function ID:
-#' 2-34
+#' 2-35
 #' 
 #' @name serially
 NULL
@@ -295,15 +324,17 @@ NULL
 #' @import rlang
 #' 
 #' @export
-serially <- function(x,
-                     ...,
-                     .list = list2(...),
-                     preconditions = NULL,
-                     actions = NULL,
-                     step_id = NULL,
-                     label = NULL,
-                     brief = NULL,
-                     active = TRUE) {
+serially <- function(
+    x,
+    ...,
+    .list = list2(...),
+    preconditions = NULL,
+    actions = NULL,
+    step_id = NULL,
+    label = NULL,
+    brief = NULL,
+    active = TRUE
+) {
   
   segments <- NULL
   
@@ -625,11 +656,13 @@ serially <- function(x,
 #' @rdname serially
 #' @import rlang
 #' @export
-expect_serially <- function(object,
-                            ...,
-                            .list = list2(...),
-                            preconditions = NULL,
-                            threshold = 1) {
+expect_serially <- function(
+    object,
+    ...,
+    .list = list2(...),
+    preconditions = NULL,
+    threshold = 1
+) {
   
   fn_name <- "expect_serially"
   
@@ -676,11 +709,13 @@ expect_serially <- function(object,
 #' @rdname serially
 #' @import rlang
 #' @export
-test_serially <- function(object,
-                          ...,
-                          .list = list2(...),
-                          preconditions = NULL,
-                          threshold = 1) {
+test_serially <- function(
+    object,
+    ...,
+    .list = list2(...),
+    preconditions = NULL,
+    threshold = 1
+) {
   
   vs <- 
     create_agent(tbl = object, label = "::QUIET::") %>%
